@@ -1,22 +1,25 @@
-import os
+#!/usr/bin/env python3.6
+# -*- encoding: utf-8 -*-
+
 from sys import path
+from os.path import dirname, join
 
-path.append(os.path.dirname(__file__))
-
-__version__=0.1
+path.append(dirname(__file__))
 
 import logging
-from delugeUtils import BASE_DIR
+from utils import BASE_DIR, ColorizeFilter
 
 logger = logging.getLogger('deluge_cli')
 logger.setLevel(logging.DEBUG)
 
-fh = logging.FileHandler(os.path.join(BASE_DIR, 'deluge_cli.log'))
+fh = logging.FileHandler(join(BASE_DIR, 'deluge_cli.log'))
 fh.setLevel(logging.DEBUG)
 ch = logging.StreamHandler()
 ch.setLevel(logging.ERROR)
 
 formatter = logging.Formatter('%(asctime)s %(levelname)8s %(name)s | %(message)s')
 fh.setFormatter(formatter)
+
 logger.addHandler(fh)
-logger.addHandler(ch)
\ No newline at end of file
+logger.addHandler(ch)
+logger.addFilter(ColorizeFilter())
\ No newline at end of file
